@@ -8,11 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-databrew-cicd", "2.0.44", __name__[0:-6], "cdk-databrew-cicd@2.0.44.jsii.tgz"
+    "cdk-databrew-cicd",
+    "2.0.108",
+    __name__[0:-6],
+    "cdk-databrew-cicd@2.0.108.jsii.tgz",
 )
 
 __all__ = [
